@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_PROPERTY_H
 #define _GLIBMM_PROPERTY_H
-/* $Id: property.h,v 1.5 2005/01/21 23:48:10 murrayc Exp $ */
+/* $Id: property.h,v 1.5.4.1 2006/05/10 13:12:39 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -21,8 +21,10 @@
  */
 
 #include <glibmm/propertyproxy.h>
-#include <glibmm/value.h>
 
+#ifdef GLIBMM_PROPERTIES_ENABLED
+
+#include <glibmm/value.h>
 
 namespace Glib
 {
@@ -166,6 +168,7 @@ Glib::PropertyProxy<T> Property<T>::get_proxy()
 
 } // namespace Glib
 
+#endif //GLIBMM_PROPERTIES_ENABLED
 
 #endif /* _GLIBMM_PROPERTY_H */
 
